==> indy-node-dev-1.0.84.tar.gz: indy-node-dev-1.0.84/sovrin_node/test/catchup/test_requests_post_multiple_new_nodes.py <==
from plenum.common.util import randomString
from plenum.test.node_catchup.helper import waitNodeDataEquality
from sovrin_client.test.client import TestClient
from sovrin_client.test.helper import getClientAddedWithRole
from sovrin_node.test.conftest import nodeThetaAdded
from sovrin_node.test.helper import TestNode


def test_requests_post_multiple_new_nodes(looper, tdirWithPoolTxns,
                                        tdirWithDomainTxnsUpdated, nodeSet,
                                        tconf, trustee, trusteeWallet,
                                        allPluginsPath, some_transactions_done):
    new_nodes = []
    for node_name in ('Zeta', 'Eta'):
        new_steward, new_steward_wallet, new_node = nodeThetaAdded(looper,
                                                                   nodeSet,
                                                                   tdirWithPoolTxns,
                                                                   tconf,
                                                                   trustee,
                                                                   trusteeWallet,
                                                                   allPluginsPath,
                                                                   TestNode,
                                                                   TestClient,
                                                                   tdirWithPoolTxns,
                                                                   node_name=node_name)
        new_nodes.append((new_steward, new_steward_wallet, new_node))

    for _ in range(5):
        getClientAddedWithRole(nodeSet, tdirWithPoolTxns, looper, trustee,
                               trusteeWallet, randomString(6))

    for (_, _, new_node) in new_nodes:
        waitNodeDataEquality(looper, new_node, *nodeSet[:-2])

    for _ in range(5):
        getClientAddedWithRole(nodeSet, tdirWithPoolTxns, looper, trustee,
                               trusteeWallet, randomString(6))

==> indy-node-dev-1.1.114.tar.gz: indy-node-dev-1.1.114/sovrin_node/test/catchup/test_requests_post_multiple_new_nodes.py <==
from plenum.common.util import randomString
from plenum.test.node_catchup.helper import waitNodeDataEquality
from sovrin_client.test.client import TestClient
from sovrin_client.test.helper import getClientAddedWithRole
from sovrin_node.test.conftest import nodeThetaAdded
from sovrin_node.test.helper import TestNode


def test_requests_post_multiple_new_nodes(
        looper,
        tdirWithPoolTxns,
        tdirWithDomainTxnsUpdated,
        nodeSet,
        tconf,
        trustee,
        trusteeWallet,
        allPluginsPath,
        some_transactions_done):
    new_nodes = []
    for node_name in ('Zeta', 'Eta'):
        new_steward, new_steward_wallet, new_node = nodeThetaAdded(looper,
                                                                   nodeSet,
                                                                   tdirWithPoolTxns,
                                                                   tconf,
                                                                   trustee,
                                                                   trusteeWallet,
                                                                   allPluginsPath,
                                                                   TestNode,
                                                                   TestClient,
                                                                   tdirWithPoolTxns,
                                                                   node_name=node_name)
        new_nodes.append((new_steward, new_steward_wallet, new_node))

    for _ in range(5):
        getClientAddedWithRole(nodeSet, tdirWithPoolTxns, looper, trustee,
                               trusteeWallet, randomString(6))

    for (_, _, new_node) in new_nodes:
        waitNodeDataEquality(looper, new_node, *nodeSet[:-2])

    for _ in range(5):
        getClientAddedWithRole(nodeSet, tdirWithPoolTxns, looper, trustee,
                               trusteeWallet, randomString(6))
